@@ -5,13 +5,14 @@ import re
 import sys
 import threading
 import time
+import warnings
 import zlib
+from abc import ABC, abstractmethod
 from contextlib import contextmanager
-from datetime import datetime
+from datetime import datetime, timezone
 from functools import wraps, partial
 
 import sentry_sdk
-from sentry_sdk._compat import text_type, utc_from_timestamp, iteritems
 from sentry_sdk.utils import (
     ContextVar,
     now,
@@ -21,13 +22,9 @@ from sentry_sdk.utils import (
     json_dumps,
 )
 from sentry_sdk.envelope import Envelope, Item
-from sentry_sdk.tracing import (
-    TRANSACTION_SOURCE_ROUTE,
-    TRANSACTION_SOURCE_VIEW,
-    TRANSACTION_SOURCE_COMPONENT,
-    TRANSACTION_SOURCE_TASK,
-)
-from sentry_sdk._types import TYPE_CHECKING
+from sentry_sdk.tracing import TransactionSource
+
+from typing import TYPE_CHECKING
 
 if TYPE_CHECKING:
     from typing import Any
@@ -53,43 +50,44 @@ if TYPE_CHECKING:
     from sentry_sdk._types import MetricValue
 
 
+warnings.warn(
+    "The sentry_sdk.metrics module is deprecated and will be removed in the next major release. "
+    "Sentry will reject all metrics sent after October 7, 2024. "
+    "Learn more: https://sentry.zendesk.com/hc/en-us/articles/26369339769883-Upcoming-API-Changes-to-Metrics",
+    DeprecationWarning,
+    stacklevel=2,
+)
+
 _in_metrics = ContextVar("in_metrics", default=False)
 _set = set  # set is shadowed below
 
 GOOD_TRANSACTION_SOURCES = frozenset(
     [
-        TRANSACTION_SOURCE_ROUTE,
-        TRANSACTION_SOURCE_VIEW,
-        TRANSACTION_SOURCE_COMPONENT,
-        TRANSACTION_SOURCE_TASK,
+        TransactionSource.ROUTE,
+        TransactionSource.VIEW,
+        TransactionSource.COMPONENT,
+        TransactionSource.TASK,
     ]
 )
 
 _sanitize_unit = partial(re.compile(r"[^a-zA-Z0-9_]+").sub, "")
 _sanitize_metric_key = partial(re.compile(r"[^a-zA-Z0-9_\-.]+").sub, "_")
 _sanitize_tag_key = partial(re.compile(r"[^a-zA-Z0-9_\-.\/]+").sub, "")
-_TAG_VALUE_SANITIZATION_TABLE = {
-    "\n": "\\n",
-    "\r": "\\r",
-    "\t": "\\t",
-    "\\": "\\\\",
-    "|": "\\u{7c}",
-    ",": "\\u{2c}",
-}
 
 
 def _sanitize_tag_value(value):
     # type: (str) -> str
-    return "".join(
-        [
-            (
-                _TAG_VALUE_SANITIZATION_TABLE[char]
-                if char in _TAG_VALUE_SANITIZATION_TABLE
-                else char
-            )
-            for char in value
-        ]
+    table = str.maketrans(
+        {
+            "\n": "\\n",
+            "\r": "\\r",
+            "\t": "\\t",
+            "\\": "\\\\",
+            "|": "\\u{7c}",
+            ",": "\\u{2c}",
+        }
     )
+    return value.translate(table)
 
 
 def get_code_location(stacklevel):
@@ -132,30 +130,37 @@ def metrics_noop(func):
     return new_func
 
 
-class Metric(object):
+class Metric(ABC):
     __slots__ = ()
 
+    @abstractmethod
+    def __init__(self, first):
+        # type: (MetricValue) -> None
+        pass
+
     @property
+    @abstractmethod
     def weight(self):
-        # type: (...) -> int
-        raise NotImplementedError()
+        # type: () -> int
+        pass
 
-    def add(
-        self, value  # type: MetricValue
-    ):
-        # type: (...) -> None
-        raise NotImplementedError()
+    @abstractmethod
+    def add(self, value):
+        # type: (MetricValue) -> None
+        pass
 
+    @abstractmethod
     def serialize_value(self):
-        # type: (...) -> Iterable[FlushedMetricValue]
-        raise NotImplementedError()
+        # type: () -> Iterable[FlushedMetricValue]
+        pass
 
 
 class CounterMetric(Metric):
     __slots__ = ("value",)
 
     def __init__(
-        self, first  # type: MetricValue
+        self,
+        first,  # type: MetricValue
     ):
         # type: (...) -> None
         self.value = float(first)
@@ -166,7 +171,8 @@ class CounterMetric(Metric):
         return 1
 
     def add(
-        self, value  # type: MetricValue
+        self,
+        value,  # type: MetricValue
     ):
         # type: (...) -> None
         self.value += float(value)
@@ -186,7 +192,8 @@ class GaugeMetric(Metric):
     )
 
     def __init__(
-        self, first  # type: MetricValue
+        self,
+        first,  # type: MetricValue
     ):
         # type: (...) -> None
         first = float(first)
@@ -203,7 +210,8 @@ class GaugeMetric(Metric):
         return 5
 
     def add(
-        self, value  # type: MetricValue
+        self,
+        value,  # type: MetricValue
     ):
         # type: (...) -> None
         value = float(value)
@@ -228,7 +236,8 @@ class DistributionMetric(Metric):
     __slots__ = ("value",)
 
     def __init__(
-        self, first  # type: MetricValue
+        self,
+        first,  # type: MetricValue
     ):
         # type(...) -> None
         self.value = [float(first)]
@@ -239,7 +248,8 @@ class DistributionMetric(Metric):
         return len(self.value)
 
     def add(
-        self, value  # type: MetricValue
+        self,
+        value,  # type: MetricValue
     ):
         # type: (...) -> None
         self.value.append(float(value))
@@ -253,7 +263,8 @@ class SetMetric(Metric):
     __slots__ = ("value",)
 
     def __init__(
-        self, first  # type: MetricValue
+        self,
+        first,  # type: MetricValue
     ):
         # type: (...) -> None
         self.value = {first}
@@ -264,7 +275,8 @@ class SetMetric(Metric):
         return len(self.value)
 
     def add(
-        self, value  # type: MetricValue
+        self,
+        value,  # type: MetricValue
     ):
         # type: (...) -> None
         self.value.add(value)
@@ -285,13 +297,13 @@ def _encode_metrics(flushable_buckets):
     out = io.BytesIO()
     _write = out.write
 
-    # Note on sanetization: we intentionally sanetize in emission (serialization)
+    # Note on sanitization: we intentionally sanitize in emission (serialization)
     # and not during aggregation for performance reasons.  This means that the
     # envelope can in fact have duplicate buckets stored.  This is acceptable for
     # relay side emission and should not happen commonly.
 
     for timestamp, buckets in flushable_buckets:
-        for bucket_key, metric in iteritems(buckets):
+        for bucket_key, metric in buckets.items():
             metric_type, metric_name, metric_unit, metric_tags = bucket_key
             metric_name = _sanitize_metric_key(metric_name)
             metric_unit = _sanitize_unit(metric_unit)
@@ -349,7 +361,7 @@ METRIC_TYPES = {
     "g": GaugeMetric,
     "d": DistributionMetric,
     "s": SetMetric,
-}
+}  # type: dict[MetricType, type[Metric]]
 
 # some of these are dumb
 TIMING_FUNCTIONS = {
@@ -364,14 +376,12 @@ TIMING_FUNCTIONS = {
 }
 
 
-class LocalAggregator(object):
+class LocalAggregator:
     __slots__ = ("_measurements",)
 
     def __init__(self):
         # type: (...) -> None
-        self._measurements = (
-            {}
-        )  # type: Dict[Tuple[str, MetricTagsInternal], Tuple[float, float, int, float]]
+        self._measurements = {}  # type: Dict[Tuple[str, MetricTagsInternal], Tuple[float, float, int, float]]
 
     def add(
         self,
@@ -418,7 +428,7 @@ class LocalAggregator(object):
         return rv
 
 
-class MetricsAggregator(object):
+class MetricsAggregator:
     ROLLUP_IN_SECONDS = 10.0
     MAX_WEIGHT = 100000
     FLUSHER_SLEEP_TIME = 5.0
@@ -512,14 +522,14 @@ class MetricsAggregator(object):
                 self._force_flush = False
             else:
                 flushable_buckets = []
-                for buckets_timestamp, buckets in iteritems(self.buckets):
+                for buckets_timestamp, buckets in self.buckets.items():
                     # If the timestamp of the bucket is newer that the rollup we want to skip it.
                     if buckets_timestamp <= cutoff:
                         flushable_buckets.append((buckets_timestamp, buckets))
 
                 # We will clear the elements while holding the lock, in order to avoid requesting it downstream again.
                 for buckets_timestamp, buckets in flushable_buckets:
-                    for _, metric in iteritems(buckets):
+                    for metric in buckets.values():
                         weight_to_remove += metric.weight
                     del self.buckets[buckets_timestamp]
 
@@ -604,7 +614,7 @@ class MetricsAggregator(object):
         if timestamp is None:
             timestamp = time.time()
         meta_key = (ty, key, unit)
-        start_of_day = utc_from_timestamp(timestamp).replace(
+        start_of_day = datetime.fromtimestamp(timestamp, timezone.utc).replace(
             hour=0, minute=0, second=0, microsecond=0, tzinfo=None
         )
         start_of_day = int(to_timestamp(start_of_day))
@@ -620,7 +630,7 @@ class MetricsAggregator(object):
                 )
 
     @metrics_noop
-    def need_code_loation(
+    def need_code_location(
         self,
         ty,  # type: MetricType
         key,  # type: str
@@ -631,7 +641,7 @@ class MetricsAggregator(object):
         if self._enable_code_locations:
             return False
         meta_key = (ty, key, unit)
-        start_of_day = utc_from_timestamp(timestamp).replace(
+        start_of_day = datetime.fromtimestamp(timestamp, timezone.utc).replace(
             hour=0, minute=0, second=0, microsecond=0, tzinfo=None
         )
         start_of_day = int(to_timestamp(start_of_day))
@@ -672,7 +682,7 @@ class MetricsAggregator(object):
             encoded_metrics = _encode_metrics(flushable_buckets)
             envelope.add_item(Item(payload=encoded_metrics, type="statsd"))
 
-        for timestamp, locations in iteritems(code_locations):
+        for timestamp, locations in code_locations.items():
             encoded_locations = _encode_locations(timestamp, locations)
             envelope.add_item(Item(payload=encoded_locations, type="metric_meta"))
 
@@ -690,14 +700,14 @@ def _serialize_tags(
         return ()
 
     rv = []
-    for key, value in iteritems(tags):
+    for key, value in tags.items():
         # If the value is a collection, we want to flatten it.
         if isinstance(value, (list, tuple)):
             for inner_value in value:
                 if inner_value is not None:
-                    rv.append((key, text_type(inner_value)))
+                    rv.append((key, str(inner_value)))
         elif value is not None:
-            rv.append((key, text_type(value)))
+            rv.append((key, str(value)))
 
     # It's very important to sort the tags in order to obtain the
     # same bucket key.
@@ -721,27 +731,25 @@ def _tags_to_dict(tags):
 
 def _get_aggregator():
     # type: () -> Optional[MetricsAggregator]
-    hub = sentry_sdk.Hub.current
-    client = hub.client
+    client = sentry_sdk.get_client()
     return (
         client.metrics_aggregator
-        if client is not None and client.metrics_aggregator is not None
+        if client.is_active() and client.metrics_aggregator is not None
         else None
     )
 
 
 def _get_aggregator_and_update_tags(key, value, unit, tags):
     # type: (str, Optional[MetricValue], MeasurementUnit, Optional[MetricTags]) -> Tuple[Optional[MetricsAggregator], Optional[LocalAggregator], Optional[MetricTags]]
-    hub = sentry_sdk.Hub.current
-    client = hub.client
-    if client is None or client.metrics_aggregator is None:
+    client = sentry_sdk.get_client()
+    if not client.is_active() or client.metrics_aggregator is None:
         return None, None, tags
 
     updated_tags = dict(tags or ())  # type: Dict[str, MetricTagValue]
     updated_tags.setdefault("release", client.options["release"])
     updated_tags.setdefault("environment", client.options["environment"])
 
-    scope = hub.scope
+    scope = sentry_sdk.get_current_scope()
     local_aggregator = None
 
     # We go with the low-level API here to access transaction information as
@@ -788,7 +796,7 @@ def increment(
 incr = increment
 
 
-class _Timing(object):
+class _Timing:
     def __init__(
         self,
         key,  # type: str
@@ -819,7 +827,7 @@ class _Timing(object):
         # type: (...) -> _Timing
         self.entered = TIMING_FUNCTIONS[self.unit]()
         self._validate_invocation("context-manager")
-        self._span = sentry_sdk.start_span(op="metric.timing", description=self.key)
+        self._span = sentry_sdk.start_span(op="metric.timing", name=self.key)
         if self.tags:
             for key, value in self.tags.items():
                 if isinstance(value, (tuple, list)):
@@ -927,7 +935,7 @@ def distribution(
 
 def set(
     key,  # type: str
-    value,  # type: MetricValue
+    value,  # type: Union[int, str]
     unit="none",  # type: MeasurementUnit
     tags=None,  # type: Optional[MetricTags]
     timestamp=None,  # type: Optional[Union[float, datetime]]
