@@ -158,13 +158,6 @@ class Transport(ABC):
         # type: (Self) -> bool
         return True
 
-    def __del__(self):
-        # type: (Self) -> None
-        try:
-            self.kill()
-        except Exception:
-            pass
-
 
 def _parse_rate_limits(header, now=None):
     # type: (str, Optional[datetime]) -> Iterable[Tuple[Optional[EventDataCategory], datetime]]
@@ -210,9 +203,7 @@ class BaseHttpTransport(Transport):
         self._disabled_until = {}  # type: Dict[Optional[EventDataCategory], datetime]
         # We only use this Retry() class for the `get_retry_after` method it exposes
         self._retry = urllib3.util.Retry()
-        self._discarded_events = defaultdict(
-            int
-        )  # type: DefaultDict[Tuple[EventDataCategory, str], int]
+        self._discarded_events = defaultdict(int)  # type: DefaultDict[Tuple[EventDataCategory, str], int]
         self._last_client_report_sent = time.time()
 
         self._pool = self._make_pool()
@@ -556,7 +547,8 @@ class BaseHttpTransport(Transport):
         raise NotImplementedError()
 
     def capture_envelope(
-        self, envelope  # type: Envelope
+        self,
+        envelope,  # type: Envelope
     ):
         # type: (...) -> None
         def send_envelope_wrapper():
@@ -869,14 +861,16 @@ class _FunctionTransport(Transport):
     """
 
     def __init__(
-        self, func  # type: Callable[[Event], None]
+        self,
+        func,  # type: Callable[[Event], None]
     ):
         # type: (...) -> None
         Transport.__init__(self)
         self._func = func
 
     def capture_event(
-        self, event  # type: Event
+        self,
+        event,  # type: Event
     ):
         # type: (...) -> None
         self._func(event)
@@ -898,9 +892,7 @@ def make_transport(options):
     use_http2_transport = options.get("_experiments", {}).get("transport_http2", False)
 
     # By default, we use the http transport class
-    transport_cls = (
-        Http2Transport if use_http2_transport else HttpTransport
-    )  # type: Type[Transport]
+    transport_cls = Http2Transport if use_http2_transport else HttpTransport  # type: Type[Transport]
 
     if isinstance(ref_transport, Transport):
         return ref_transport
